==> _private_core_network-1.1.5.tar.gz: lib/network_resources/provider/client_web.dart <==
import 'dart:convert';

import 'package:_private_core_network/options.dart';
import 'package:dio/browser.dart';
import 'package:dio/dio.dart';
import 'package:flutter/foundation.dart';
import 'package:logger/logger.dart';
import 'package:_private_core/_private_core.dart';

const String methodGet = "GET";
const String methodPost = "POST";
const String methodPut = "PUT";
const String methodDelete = "DELETE";

_parseAndDecode(String response) {
  return jsonDecode(response);
}

parseJson(String text) {
  return compute(_parseAndDecode, text);
}

class AppClientsWeb extends DioForBrowser {
  static final _logger = Logger();
  static AppClientsWeb? _instance;
  static bool _enableErrorHandler = true;

  factory AppClientsWeb(
      {required bool requiredToken,
      bool isAuthorizationCustom = false,
      String? token,
      String? baseUrl,
      bool enableErrorHandler = true,
      BaseOptions? options}) {
    _enableErrorHandler = enableErrorHandler;

    _instance ??=
        AppClientsWeb._(baseUrl: baseUrl ?? appBaseUrl, options: options);
    if (options != null) _instance!.options = options;
    _instance!.options.baseUrl = baseUrl ?? appBaseUrl;
    (_instance!.transformer as BackgroundTransformer).jsonDecodeCallback =
        parseJson;
    if ((token == null || token.isEmpty)) {
      if (requiredToken) {
        _logger.w('Request RequiredToken but your token is null!');
      }
      _instance!.options.headers.remove(r'Authorization');
    } else if (requiredToken) {
      _instance!.options.headers.addAll({
        r'Authorization': isAuthorizationCustom ? token : ('Bearer $token')
      });
    }
    _logger.i("Header: ${_instance!.options.headers}");
    _instance!.options.headers.addAll({
      "Access-Control-Allow-Origin": "*",
      "Access-Control-Allow-Credentials": true,
      "Access-Control-Allow-Headers":
          "Origin,Content-Type,X-Amz-Date,Authorization,X-Api-Key,X-Amz-Security-Token,locale",
      "Access-Control-Allow-Methods": "POST, OPTIONS"
    });
    return _instance!;
  }

  AppClientsWeb._({String? baseUrl, BaseOptions? options}) : super(options) {
    interceptors.add(InterceptorsWrapper(
      onRequest: _requestInterceptor,
      onResponse: _responseInterceptor,
      onError: _errorInterceptor,
    ));
    this.options.baseUrl = baseUrl ?? appBaseUrl;
  }

  _requestInterceptor(
      RequestOptions ops, RequestInterceptorHandler handler) async {
    String message =
        "${ops.method}: ${ops.uri}\nQueryParameters: ${ops.queryParameters}";
    switch (ops.method) {
      case methodGet:
        break;
      case methodPost:
      case methodPut:
      case methodDelete:
        if (ops.data is Map) {
          message += "\nData is Map: ${ops.data}";
        } else if (ops.data is FormData) {
          message +=
              "\nData is FormData: ${ops.data.fields}\nFiles: ${ops.data.files}";
        }
        break;
      default:
        break;
    }
    _logger.d(message);
    ops.connectTimeout = const Duration(seconds: 30000);
    ops.receiveTimeout = const Duration(seconds: 30000);
    handler.next(ops);
  }

  _responseInterceptor(Response r, ResponseInterceptorHandler handler) {
    _logger.i(
        "Response ${r.requestOptions.uri}: ${r.statusCode}\nData: ${r.data}");
    handler.next(r);
  }

  _errorInterceptor(DioError e, ErrorInterceptorHandler handler) {
    _logger.wtf(
        "${e.requestOptions.uri}\n${e.type} - ${e.message}\nStatus: ${e.response?.statusCode} -  ${e.response?.statusMessage}\nData: ${e.response?.data}");
    // if (_enableErrorHandler) ErrorHandling().onError(dioError);
    if (PCoreConfig.instance.coreOptions.errorInterceptor != null) {
      PCoreConfig.instance.coreOptions.errorInterceptor!(e);
    }
    handler.next(e);
  }
}

==> _private_core_network-1.2.8.tar.gz: lib/network_resources/provider/client_web.dart <==
import 'dart:convert';

import 'package:_private_core_network/options.dart';
import 'package:dio/browser.dart';
import 'package:dio/dio.dart';
import 'package:flutter/foundation.dart';
import 'package:logger/logger.dart';
import 'package:_private_core/_private_core.dart';

const String methodGet = "GET";
const String methodPost = "POST";
const String methodPut = "PUT";
const String methodDelete = "DELETE";

_parseAndDecode(String response) {
  return jsonDecode(response);
}

parseJson(String text) {
  return compute(_parseAndDecode, text);
}

class AppClient extends DioForBrowser {
  static final _logger = Logger();
  static AppClient? _instance;
  static bool _enableErrorHandler = true;

  factory AppClient(
      {required bool requiredToken,
      bool isAuthorizationCustom = false,
      String? token,
      String? baseUrl,
      bool enableErrorHandler = true,
      BaseOptions? options}) {
    _enableErrorHandler = enableErrorHandler;

    _instance ??= AppClient._(baseUrl: baseUrl ?? appBaseUrl, options: options);
    if (options != null) _instance!.options = options;
    _instance!.options.baseUrl = baseUrl ?? appBaseUrl;
    (_instance!.transformer as BackgroundTransformer).jsonDecodeCallback =
        parseJson;
    if ((token == null || token.isEmpty)) {
      if (requiredToken) {
        _logger.w('Request RequiredToken but your token is null!');
      }
      _instance!.options.headers.remove(r'Authorization');
    } else if (requiredToken) {
      _instance!.options.headers.addAll({
        r'Authorization': isAuthorizationCustom ? token : ('Bearer $token')
      });
    }
    _logger.i("Header: ${_instance!.options.headers}");
    _instance!.options.headers.addAll({
      "Access-Control-Allow-Origin": "*",
      "Access-Control-Allow-Credentials": true,
      "Access-Control-Allow-Headers":
          "Origin,Content-Type,X-Amz-Date,Authorization,X-Api-Key,X-Amz-Security-Token,locale",
      "Access-Control-Allow-Methods": "POST, OPTIONS"
    });
    return _instance!;
  }

  AppClient._({String? baseUrl, BaseOptions? options}) : super(options) {
    interceptors.add(InterceptorsWrapper(
      onRequest: _requestInterceptor,
      onResponse: _responseInterceptor,
      onError: _errorInterceptor,
    ));
    this.options.baseUrl = baseUrl ?? appBaseUrl;
  }

  _requestInterceptor(
      RequestOptions ops, RequestInterceptorHandler handler) async {
    String message =
        "${ops.method}: ${ops.uri}\nQueryParameters: ${ops.queryParameters}";
    switch (ops.method) {
      case methodGet:
        break;
      case methodPost:
      case methodPut:
      case methodDelete:
        if (ops.data is Map) {
          message += "\nData is Map: ${ops.data}";
        } else if (ops.data is FormData) {
          message +=
              "\nData is FormData: ${ops.data.fields}\nFiles: ${ops.data.files}";
        }
        break;
      default:
        break;
    }
    _logger.d(message);
    ops.connectTimeout = const Duration(seconds: 30000);
    ops.receiveTimeout = const Duration(seconds: 30000);
    handler.next(ops);
  }

  _responseInterceptor(Response r, ResponseInterceptorHandler handler) {
    _logger.i(
        "Response ${r.requestOptions.uri}: ${r.statusCode}\nData: ${r.data}");
    handler.next(r);
  }

  _errorInterceptor(DioError e, ErrorInterceptorHandler handler) {
    _logger.wtf(
        "${e.requestOptions.uri}\n[${e.type}][${e.response?.statusCode}] ${e.message ?? ""}\nData: ${e.response?.data}");
    // if (_enableErrorHandler) ErrorHandling().onError(dioError);
    if (PCoreConfig.instance.coreOptions.errorInterceptor != null) {
      PCoreConfig.instance.coreOptions.errorInterceptor!(e);
    }
    handler.next(e);
  }
}
